@@ -542,7 +542,8 @@ ci.or.exact <-
 
       ci[ci < -1] <- -1
       ci[ci > 1] <- 1
-    }
+    } else 
+      stop("Confidence interval measure ", measure, "not implemented!")
 
     ci
   }
