@@ -1,10 +1,12 @@
 options(digits = 2)
 
-data <- list(c("A", "B"),
+data <- list(
+  c("A", "B"),
   c("A", "B", "C", "G"),
   c("C", "D"),
   c("C", "D"),
-  c("E", "F"))
+  c("E", "F")
+)
 
 trans <- transactions(data)
 
@@ -17,16 +19,16 @@ trans <- transactions(data)
 
 # complains about low support
 fsets <-
-    eclat(
-      trans,
-      parameter = list(supp = 0),
-      control = list(verb = FALSE)
-    )
+  eclat(
+    trans,
+    parameter = list(supp = 0),
+    control = list(verb = FALSE)
+  )
 
 # add all-confidence
 quality(fsets)$allConfidence <-
   interestMeasure(fsets, measure = "allConfidence", trans)
-#inspect(fsets[order(size(fsets))])
+# inspect(fsets[order(size(fsets))])
 
 # check
 ac <-
@@ -78,7 +80,8 @@ expect_equal(nrow(m5), 0L)
 
 rules <- apriori(trans,
   parameter = list(supp = 0.01, conf = 0.5),
-  control = list(verb = FALSE))
+  control = list(verb = FALSE)
+)
 
 ## calculate all measures (just to see if one creates an error)
 m1 <- interestMeasure(rules, transactions = trans)
@@ -94,8 +97,10 @@ expect_equal(nrow(m2), 1L)
 
 ## coverage
 expect_equal(coverage(rules), support(lhs(rules), trans = trans))
-expect_equal(coverage(rules, trans = trans, reuse = FALSE),
-  support(lhs(rules), trans = trans))
+expect_equal(
+  coverage(rules, trans = trans, reuse = FALSE),
+  support(lhs(rules), trans = trans)
+)
 
 ## check for empty ruleset
 m4 <- interestMeasure(rules[0], transactions = trans)
@@ -109,8 +114,8 @@ red <- is.redundant(rules)
 imp <- interestMeasure(rules, measure = "improvement")
 expect_equal(red, imp <= 0)
 
-#inspect(rules[!red])
-#inspect(rules[red])
+# inspect(rules[!red])
+# inspect(rules[red])
 
 # test support
 s_tid <- support(rules, trans, control = list(method = "tidlist"))
@@ -127,13 +132,14 @@ rules <- apriori(Adult,
     supp = 0.5,
     conf = 0.9,
     target = "rules"
-  ), control = list(verb = FALSE))
+  ), control = list(verb = FALSE)
+)
 
 m_r <- interestMeasure(rules, transactions = Adult, reuse = TRUE)
 m <- interestMeasure(rules, transactions = Adult, reuse = FALSE)
 expect_equal(m_r, m)
 
-#dput(round(m_r, 3))
+# dput(round(m_r, 3))
 m_previous <- structure(
   list(
     support = c(
@@ -502,7 +508,7 @@ m_previous <- structure(
       -0.005,
       -0.005,
       0.012,
-      0.027,-0.007,
+      0.027, -0.007,
       0,
       0.009,
       -0.001,
@@ -687,35 +693,35 @@ m_previous <- structure(
       0.922,
       -0.003,
       -0.002,
-      -0.001,-0.001,
+      -0.001, -0.001,
       -0.004,
       -0.004,
       -0.003,
       -0.003,
       -0.001,
       0.905,
-      -0.014,-0.007,
+      -0.014, -0.007,
       -0.014,
       -0.007,
       -0.012,
       -0.007,
       -0.003,
       -0.002,
-      -0.002,-0.001,
+      -0.002, -0.001,
       -0.004,
       -0.003,
       -0.004,
       -0.001,
       -0.003,
       -0.001,
-      -0.006,-0.007,
+      -0.006, -0.007,
       -0.005,
       -0.006,
       -0.009,
       -0.003,
       -0.002,
       -0.013,
-      -0.003,-0.009,
+      -0.003, -0.009,
       -0.005,
       -0.007,
       -0.005,
@@ -1004,7 +1010,7 @@ m_previous <- structure(
       0.036,
       0.023,
       0.195,
-      -0.027,-0.019,
+      -0.027, -0.019,
       -0.016,
       -0.01,
       -0.066,
@@ -1012,7 +1018,7 @@ m_previous <- structure(
       0.009,
       0.035,
       0.091,
-      0.174,-0.062,
+      0.174, -0.062,
       -0.042,
       -0.061,
       -0.041,
@@ -1029,7 +1035,7 @@ m_previous <- structure(
       -0.026,
       0.159,
       -0.055,
-      -0.056,-0.052,
+      -0.056, -0.052,
       -0.05,
       -0.046,
       0.08,
@@ -1037,7 +1043,7 @@ m_previous <- structure(
       -0.066,
       0.001,
       0.059,
-      -0.011,-0.001,
+      -0.011, -0.001,
       -0.009,
       0.004,
       -0.057,
@@ -1055,7 +1061,7 @@ m_previous <- structure(
       0.011,
       0.168,
       -0.021,
-      -0.011,-0.014,
+      -0.011, -0.014,
       -0.007,
       -0.051,
       -0.087,
@@ -1063,7 +1069,7 @@ m_previous <- structure(
       0.02,
       0.056,
       0.125,
-      -0.035,-0.018,
+      -0.035, -0.018,
       -0.034,
       -0.018,
       -0.03,
@@ -1071,7 +1077,7 @@ m_previous <- structure(
       0.009,
       0.004,
       0.012,
-      0.006,-0.001,
+      0.006, -0.001,
       0.009,
       -0.021,
       0.105,
@@ -1079,7 +1085,7 @@ m_previous <- structure(
       0.124,
       -0.028,
       -0.04,
-      -0.029,-0.039,
+      -0.029, -0.039,
       -0.02,
       0.049,
       0.111,
@@ -1087,7 +1093,7 @@ m_previous <- structure(
       0.001,
       0.036,
       -0.005,
-      -0.001,-0.004,
+      -0.001, -0.004,
       0.002,
       -0.027,
       -0.036,
@@ -1368,14 +1374,14 @@ m_previous <- structure(
       0,
       0.032,
       0.014,
-      -0.046,-0.024,
+      -0.046, -0.024,
       0.027,
       0.014,
       0.191,
       -0.026,
       -0.016,
       -0.016,
-      -0.009,-0.063,
+      -0.009, -0.063,
       -0.063,
       0.004,
       0.021,
@@ -1383,7 +1389,7 @@ m_previous <- structure(
       0.139,
       -0.039,
       -0.021,
-      -0.04,-0.021,
+      -0.04, -0.021,
       -0.035,
       0.048,
       0.01,
@@ -1391,7 +1397,7 @@ m_previous <- structure(
       0.014,
       0.007,
       -0.001,
-      0.011,-0.027,
+      0.011, -0.027,
       0.129,
       -0.019,
       0.15,
@@ -1408,7 +1414,7 @@ m_previous <- structure(
       -0.005,
       -0.001,
       -0.004,
-      0.002,-0.036,
+      0.002, -0.036,
       -0.046,
       0.103
     ),
@@ -1640,7 +1646,7 @@ m_previous <- structure(
       0.237,
       -0.037,
       -0.035,
-      -0.018,-0.016,
+      -0.018, -0.016,
       -0.09,
       -0.049,
       0.038,
@@ -1648,7 +1654,7 @@ m_previous <- structure(
       0.225,
       0.345,
       -0.173,
-      -0.16,-0.168,
+      -0.16, -0.168,
       -0.151,
       -0.251,
       0.166,
@@ -1665,7 +1671,7 @@ m_previous <- structure(
       -0.132,
       -0.09,
       -0.109,
-      -0.069,-0.193,
+      -0.069, -0.193,
       0.21,
       0.333,
       -0.274,
@@ -1683,14 +1689,14 @@ m_previous <- structure(
       0,
       0,
       0.012,
-      0.005,-0.012,
+      0.005, -0.012,
       -0.006,
       0.007,
       0.003,
       0.024,
       -0.003,
       -0.002,
-      -0.001,-0.001,
+      -0.001, -0.001,
       -0.004,
       -0.004,
       0.002,
@@ -1698,7 +1704,7 @@ m_previous <- structure(
       0.023,
       0.05,
       -0.014,
-      -0.007,-0.014,
+      -0.007, -0.014,
       -0.007,
       -0.012,
       0.017,
@@ -1714,7 +1720,7 @@ m_previous <- structure(
       0.023,
       -0.006,
       -0.007,
-      -0.005,-0.006,
+      -0.005, -0.006,
       -0.009,
       0.022,
       0.048,
@@ -2229,14 +2235,14 @@ m_previous <- structure(
       -0.002,
       -0.001,
       -0.001,
-      -0.004,-0.004,
+      -0.004, -0.004,
       0.002,
       0.009,
       0.023,
       0.05,
       -0.014,
       -0.007,
-      -0.014,-0.007,
+      -0.014, -0.007,
       -0.012,
       0.017,
       0.004,
@@ -2244,14 +2250,14 @@ m_previous <- structure(
       0.004,
       0.002,
       0,
-      0.003,-0.004,
+      0.003, -0.004,
       0.023,
       -0.003,
       0.023,
       -0.006,
       -0.007,
       -0.005,
-      -0.006,-0.009,
+      -0.006, -0.009,
       0.022,
       0.048,
       -0.013,
@@ -2276,14 +2282,14 @@ m_previous <- structure(
       0.003,
       0.027,
       -0.003,
-      -0.002,-0.002,
+      -0.002, -0.002,
       -0.001,
       -0.004,
       -0.004,
       0.002,
       0.009,
       0.026,
-      0.059,-0.016,
+      0.059, -0.016,
       -0.008,
       -0.015,
       -0.007,
@@ -2299,7 +2305,7 @@ m_previous <- structure(
       0.025,
       -0.003,
       0.026,
-      -0.006,-0.008,
+      -0.006, -0.008,
       -0.005,
       -0.006,
       -0.009,
@@ -2326,7 +2332,7 @@ m_previous <- structure(
       0.134,
       0.113,
       0.587,
-      -0.152,-0.139,
+      -0.152, -0.139,
       -0.102,
       -0.085,
       -1,
@@ -2334,7 +2340,7 @@ m_previous <- structure(
       0.044,
       0.127,
       0.289,
-      0.457,-0.236,
+      0.457, -0.236,
       -0.211,
       -0.235,
       -0.204,
@@ -2349,7 +2355,7 @@ m_previous <- structure(
       -0.15,
       0.446,
       -0.164,
-      0.495,-0.378,
+      0.495, -0.378,
       -0.303,
       -0.394,
       -0.303,
@@ -2425,21 +2431,21 @@ m_previous <- structure(
       0,
       0,
       2.062,
-      0.861,-2.309,
+      0.861, -2.309,
       -1.148,
       1.254,
       0.607,
       5.242,
       -0.653,
       -0.345,
-      -0.324,-0.157,
+      -0.324, -0.157,
       -0.912,
       -0.912,
       0.298,
       1.484,
       4.126,
       9.256,
-      -2.532,-1.302,
+      -2.532, -1.302,
       -2.472,
       -1.238,
       -2.069,
@@ -2454,7 +2460,7 @@ m_previous <- structure(
       4.715,
       -0.572,
       4.869,
-      -1.237,-1.544,
+      -1.237, -1.544,
       -1.044,
       -1.21,
       -1.5,
@@ -2477,7 +2483,7 @@ m_previous <- structure(
       -6.871,
       -3.891,
       7.696,
-      5.185,-4.177,
+      5.185, -4.177,
       -2.743,
       -15.504,
       2.178,
@@ -2500,7 +2506,7 @@ m_previous <- structure(
       -1.332,
       -2.693,
       -1.77,
-      0.298,-1.917,
+      0.298, -1.917,
       3.067,
       -13.945,
       2.583,
@@ -2533,7 +2539,7 @@ m_previous <- structure(
       0.01,
       0.005,
       0.087,
-      -0.01,-0.005,
+      -0.01, -0.005,
       -0.007,
       -0.003,
       -0.023,
@@ -2557,7 +2563,7 @@ m_previous <- structure(
       -0.01,
       0.052,
       -0.006,
-      0.063,-0.013,
+      0.063, -0.013,
       -0.019,
       -0.013,
       -0.018,
@@ -2899,23 +2905,28 @@ m_previous <- structure(
       682,
       2078
     ),
-    relativeRisk = c(NaN, NaN, 1.031, 1.013, 0.961, 0.981, 1.024, 1.011, 1.222, 
-      0.977, 0.988, 0.984, 0.993, 0.949, 0.913, 1.004, 1.022, 1.065, 
-      1.16, 0.963, 0.981, 0.963, 0.982, 0.969, 1.048, 1.009, 1.004, 
-      1.013, 1.006, 0.999, 1.01, 0.977, 1.128, 0.986, 1.156, 0.971, 
-      0.958, 0.971, 0.959, 0.98, 1.056, 1.14, 0.971, 1.001, 1.041, 
-      0.995, 0.999, 0.996, 1.002, 0.972, 0.962, 1.099),
-    LIC = c(Inf, Inf, 1.013, 1.005, 0.987, 0.993, 1.007, 1.003, Inf, 0.997, 
-            0.998, 0.998, 0.999, 0.996, 0.996, 0.997, 0.997, 0.999, Inf, 
-            0.984, 0.992, 0.985, 0.993, 0.988, 0.992, 0.997, 0.998, 0.998, 
-            0.999, 0.996, 0.996, 0.995, 0.998, 0.997, 0.999, 0.994, 0.992, 
-            0.995, 0.994, 0.991, 0.997, 0.998, 0.987, 0.997, 0.991, 0.994, 
-            0.993, 0.995, 0.994, 0.992, 0.99, 0.997)
+    relativeRisk = c(
+      NaN, NaN, 1.031, 1.013, 0.961, 0.981, 1.024, 1.011, 1.222,
+      0.977, 0.988, 0.984, 0.993, 0.949, 0.913, 1.004, 1.022, 1.065,
+      1.16, 0.963, 0.981, 0.963, 0.982, 0.969, 1.048, 1.009, 1.004,
+      1.013, 1.006, 0.999, 1.01, 0.977, 1.128, 0.986, 1.156, 0.971,
+      0.958, 0.971, 0.959, 0.98, 1.056, 1.14, 0.971, 1.001, 1.041,
+      0.995, 0.999, 0.996, 1.002, 0.972, 0.962, 1.099
+    ),
+    LIC = c(
+      Inf, Inf, 1.013, 1.005, 0.987, 0.993, 1.007, 1.003, Inf, 0.997,
+      0.998, 0.998, 0.999, 0.996, 0.996, 0.997, 0.997, 0.999, Inf,
+      0.984, 0.992, 0.985, 0.993, 0.988, 0.992, 0.997, 0.998, 0.998,
+      0.999, 0.996, 0.996, 0.995, 0.998, 0.997, 0.999, 0.994, 0.992,
+      0.995, 0.994, 0.991, 0.997, 0.998, 0.987, 0.997, 0.991, 0.994,
+      0.993, 0.995, 0.994, 0.992, 0.99, 0.997
+    )
   ),
-  row.names = c(NA,-52L),
+  row.names = c(NA, -52L),
   class = "data.frame"
 )
 
-if (!all(setequal(names(m_previous), names(m_r))))
+if (!all(setequal(names(m_previous), names(m_r)))) {
   warning("Not all interestMeasures are tested! Missing data for: ", paste(setdiff(names(m_r), names(m_previous)), collapse = ", "))
+}
 expect_equivalent(m_previous, round(m_r[names(m_previous)], 3))
